@@ -9,9 +9,12 @@ use Apache::Session::Generate::MD5;
 use Apache::Session::Serialize::Base64;
 use Apache::Session::Browseable::DBI;
 
-our $VERSION = '0.2';
+our $VERSION = '0.8';
 our @ISA     = qw(Apache::Session::Browseable::DBI Apache::Session);
 
+*serialize   = \&Apache::Session::Serialize::Base64::serialize;
+*unserialize = \&Apache::Session::Serialize::Base64::unserialize;
+
 sub populate {
     my $self = shift;
 
@@ -20,8 +23,8 @@ sub populate {
     $self->{lock_manager} = new Apache::Session::Lock::Null $self;
     $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
     $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
-    $self->{serialize}    = \&Apache::Session::Serialize::Base64::serialize;
-    $self->{unserialize}  = \&Apache::Session::Serialize::Base64::unserialize;
+    $self->{serialize}    = \&serialize;
+    $self->{unserialize}  = \&unserialize;
 
     return $self;
 }
